##  Monitor KPIs for AI Agents on the Architecture Executive Dashboard
Monitor KPIs from the AI Agent Hub group on the architecture executive dashboard to analyze how your agentic portfolio changes compared to past periods. To learn how to configure and use this dashboard, see [Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "The architecture executive dashboard provides essential KPIs related to the organization’s IT landscape, enabling informed, data-driven decision-making through valuable insights.").
KPIs for AI agents include:
  * Cost saving
  * Agents portfolio
  * Agents quality seal
  * Approved agents
  * Risk reduction
  * Revenue increase


You can select up to 4 KPIs to display on the dashboard. To learn how to do it, see [Selecting Displayed KPIs](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD#loio439deba0a1984e0a91c0cc5e86509156__section_hxb_krm_5fc).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio5439cd9fef43498eb20d1a5317e97b09_LowRes.png)
KPIs for AI Agents on the Architecture Executive Dashboard
YesNo
Send
